<?php

namespace MovieSite\MovieSite\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use MovieSite\MovieSite\Forms\MovieSite as MovieSiteForm;
use MovieSite\MovieSite\Http\Requests\MovieSiteRequest;
use MovieSite\MovieSite\Interfaces\MovieSiteRepositoryInterface;
use MovieSite\MovieSite\Repositories\Eloquent\Filters\MovieSiteResourceFilter;
use MovieSite\MovieSite\Repositories\Eloquent\Presenters\MovieSiteListPresenter;

/**
 * Resource controller class for movie_site.
 */
class MovieSiteResourceController extends BaseController
{

    /**
     * Initialize movie_site resource controller.
     *
     *
     * @return null
     */
    public function __construct(MovieSiteRepositoryInterface $movie_site)
    {
        parent::__construct();
        $this->form = MovieSiteForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('movie_site.movie_site.modules'), 'movie_site', guard_url('movie_site'));
        $this->repository = $movie_site;
    }

    /**
     * Display a list of movie_site.
     *
     * @return Response
     */
    public function index(MovieSiteRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(MovieSiteResourceFilter::class)
            ->setPresenter(MovieSiteListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('movie_site::movie_site.names'))
            ->view('movie_site::movie_site.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display movie_site.
     *
     * @param Request $request
     * @param Model   $movie_site
     *
     * @return Response
     */
    public function show(MovieSiteRequest $request, MovieSiteRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('movie_site::movie_site.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('movie_site::movie_site.show')
            ->output();
    }

    /**
     * Show the form for creating a new movie_site.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(MovieSiteRequest $request, MovieSiteRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('movie_site::movie_site.name'))
            ->view('movie_site::movie_site.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new movie_site.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MovieSiteRequest $request, MovieSiteRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('movie_site::movie_site.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('movie_site/movie_site/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/movie_site/movie_site'))
                ->redirect();
        }

    }

    /**
     * Show movie_site for editing.
     *
     * @param Request $request
     * @param Model   $movie_site
     *
     * @return Response
     */
    public function edit(MovieSiteRequest $request, MovieSiteRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('movie_site::movie_site.name'))
            ->view('movie_site::movie_site.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the movie_site.
     *
     * @param Request $request
     * @param Model   $movie_site
     *
     * @return Response
     */
    public function update(MovieSiteRequest $request, MovieSiteRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('movie_site::movie_site.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('movie_site/movie_site/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('movie_site/movie_site/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the movie_site.
     *
     * @param Model   $movie_site
     *
     * @return Response
     */
    public function destroy(MovieSiteRequest $request, MovieSiteRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('movie_site::movie_site.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('movie_site/movie_site/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('movie_site/movie_site/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
