<?php

namespace MovieSite\MovieSite\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use MovieSite\MovieSite\Http\Requests\MovieSiteRequest;
use MovieSite\MovieSite\Models\MovieSite;

/**
 * Admin web controller class.
 */
class MovieSiteWorkflowController extends BaseController
{

    /**
     * Workflow controller function for movie_site.
     *
     * @param Model   $movie_site
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(MovieSiteRequest $request, MovieSite $movie_site, $step)
    {

        try {

            $movie_site->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('movie_site::movie_site.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/movie_site/movie_site/' . $movie_site->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/movie_site/movie_site/' . $movie_site->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for movie_site.
     *
     * @param Model   $movie_site
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(MovieSite $movie_site, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $movie_site->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('movie_site::movie_site.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('movie_site::admin.movie_site.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('movie_site::admin.movie_site.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('movie_site::admin.movie_site.message', $data)->render();

        }

    }
}
