<?php

namespace MovieSite\MovieSite\Providers;

use Illuminate\Support\ServiceProvider;
use MovieSite\MovieSite\MovieSites;

class MovieSiteServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'movie_site');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'movie_site');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\MovieSite\MovieSite\Providers\AuthServiceProvider::class);
        $this->app->register(\MovieSite\MovieSite\Providers\RouteServiceProvider::class);
        // $this->app->register(\MovieSite\MovieSite\Providers\EventServiceProvider::class);
        // $this->app->register(\MovieSite\MovieSite\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('movie_site.movie_site', function($app)
        {
            return $this->app->make(MovieSites::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind MovieSite to repository
        $this->app->bind(
            'MovieSite\MovieSite\Interfaces\MovieSiteRepositoryInterface',
            \MovieSite\MovieSite\Repositories\Eloquent\MovieSiteRepository::class
        );
    }


    /**
     * Merges user's and movie_site's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'movie_site.movie_site'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \MovieSite\MovieSite\Commands\MovieSite::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['movie_site.movie_site'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('movie_site/movie_site.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/movie_site')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/movie_site')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
